import { dataSource } from "../../../data-source";
import { protocolAgenda } from "../../../entity/club/protocol/protocolAgenda";
import DatabaseActionException from "../../../exceptions/databaseActionException";
import InternalException from "../../../exceptions/internalException";
import { SynchronizeProtocolAgendaCommand } from "./protocolAgendaCommand";

export default abstract class ProtocolAgendaCommandHandler {
  /**
   * @description create protocolAgenda
   * @param {number} protocolId
   * @returns {Promise<number>}
   */
  static async create(protocolId: number): Promise<number> {
    return await dataSource
      .createQueryBuilder()
      .insert()
      .into(protocolAgenda)
      .values({
        topic: "",
        context: "",
        protocolId,
      })
      .execute()
      .then((result) => {
        return result.identifiers[0].id;
      })
      .catch((err) => {
        throw new DatabaseActionException("CREATE", "protocolAgenda", err);
      });
  }

  /**
   * @description sync protocolAgenda
   * @param {Array<SynchronizeProtocolAgendaCommand>} syncProtocolAgenda
   * @returns {Promise<void>}
   */
  static async sync(syncProtocolAgenda: Array<SynchronizeProtocolAgendaCommand>): Promise<void> {
    return await dataSource
      .createQueryBuilder()
      .insert()
      .into(protocolAgenda)
      .values(syncProtocolAgenda)
      .orUpdate(["topic", "context"], ["id"])
      .execute()
      .then(() => {})
      .catch((err) => {
        throw new DatabaseActionException("SYNC", "protocolAgenda", err);
      });
  }
}
